| jointPeaks | R Documentation |
Construct a joint peak object by retrieval of peak streamflows for two sites and joining the union of the peaks by water year and create empirical probabilities of the bivariate relation. This function is especially helpful when one is studying joint probabilities in peaks.
jointPeaks(Asite_no="--", Bsite_no="--", appearsSystematic=FALSE, a=0,
Adf=NULL, Bdf=NULL, ...)
Asite_no |
The “A site” (think horizontal axis) |
Bsite_no |
The “B site” (think horizontal axis) |
appearsSystematic |
Whereas one might want only to do the univariate marginal distributional analysis and not rely on non-systematic record without more sophisticated analysis methods of censored information, a decision is made to have the default for this argument false so as to maximize information into the deep tail of the bivariate relation between the peaks at the two sites. Remember that if copulas were to be used in analyses of the joint distribution that such operations are in probability space and not the real space of the analysis. We think better deep-tail information is available if the default is false. See also the |
a |
A value for the plotting-position formula from package lmomco |
Adf |
An optional data frame of “peaks” to supercede the retrieval of peaks. This feature is useful if a user want to inject another quantity, such as flood volume, into this function. The |
Bdf |
An optional data frame of “peaks” to supercede the retrieval of peaks. This feature is useful if a user want to inject another quantity, such as flood volume, into this function. The |
... |
Other arguments to pass (if ever needed). |
A list is returned with elements:
Asite_no |
Data frame of the entire period of record for the |
Bsite_no |
Data frame of the entire period of record for the |
AB |
Data frame as the joint peak object containing the pairwise matches in peaks and influenced or not by |
W.H. Asquith
Original R by WHA for this package.
splitPeakCodes
## Not run:
AB <- jointPeaks("08167000", "08167500") #
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.